# lifted from https://gist.github.com/simonw/bac2bfb7973832d97d7b023898eae885

import zipfile
import json
import sqlite_utils
import click
import arrow


@click.group()
def cli():
    pass

@cli.command()
@click.option("--db", type=str, default="/home/rrix/sync/akkoma.db")
def pdb(db):
    db = sqlite_utils.Database(db)
    db.enable_wal()
    
    print("try something like [print(it['content']) for it in db['Create'].search('bilbo')]")
    import pdb;
    pdb.set_trace()

@cli.command()
@click.option("--db", type=str, default="/home/rrix/sync/akkoma.db")
@click.option("--query", type=str, default="arcology")
def search(db, query):
    db = sqlite_utils.Database(db)
    db.enable_wal()
    
    for it in db['Create'].search(query, order_by="published asc"):
        print(print_one(it))


def print_one(activity):
    """
    Dark laughter.
    """
    props = f""":PROPERTIES:
:ID: {activity.get("id")}
:END:
"""

    ptime = arrow.get(activity.get("published"))

    heading = f'* [{ptime.format("YYYY-MM-DD ddd HH:MM")}] [{activity.get("summary", "Post:")}]'

    text = f'{activity.get("source")}'
    if "\n" not in text:
        heading += f" {text}"

    reply_maybe = ""
    if activity.get("inReplyTo"):
      reply_maybe = f'[[{activity.get("inReplyTo")}][in reply to...]]\n'

    src = f"""#+BEGIN_SRC json
{json.dumps(activity, indent=2)}
#+END_SRC
"""

    return ''.join([
        heading,
        "\n",
        props,
        text,
        "\n\n",
        reply_maybe,
        "\n\n",
        src,
    ])

@cli.command()
@click.option("--db", type=str, default="/home/rrix/sync/akkoma.db")
@click.option("--zip-file", type=str, default="/home/rrix/sync/akkoma-export.zip")
def run(db, zip_file):
    db = sqlite_utils.Database(db)
    db.enable_wal()

    try:
        db["Create"].enable_fts(["summary", "source", "content", "to"],
                                create_triggers=True, tokenize="porter")
    except:
        pass
    
    with zipfile.ZipFile(zip_file, mode='r') as z:
        obj = json.loads(z.read("outbox.json"))

        with click.progressbar(obj['orderedItems']) as bar:
            for item in bar:
                event_type = item['type']

                if event_type == "Create":
                    decoded = item['object']
                    # potentially swap post source
                    if isinstance(decoded['source'], dict):
                        decoded['source'] = decoded['source']['content'];
                    db[event_type].insert(decoded, pk="id", alter=True, replace=True)
                elif event_type == "Announce":
                    db[event_type].insert(item, pk="id", alter=True, replace=True)
                else:
                    raise f"Unsupported event type {event_type}"

    db["Create"].optimize()
